Module: RSMP::Validator::AsyncContext
- Defined in:
- lib/rsmp/validator/async_context.rb
Overview
Sus fixture module that runs each test inside the shared Async reactor. Include this in the sus base class to ensure all tests run within the reactor context.